@@ -7,7 +7,10 @@ from typing import Any, Dict, List, Optional, Text, Tuple
 
 from rasa import telemetry
 from rasa.core.policies.policy import PolicyPrediction
+from rasa.nlu.test import EntityEvaluationResult, evaluate_entities
+from rasa.shared.core.constants import POLICIES_THAT_EXTRACT_ENTITIES
 from rasa.shared.exceptions import RasaException
+from rasa.shared.nlu.training_data.message import Message
 import rasa.shared.utils.io
 from rasa.core.channels import UserMessage
 from rasa.shared.core.training_data.story_writer.yaml_story_writer import (
@@ -18,6 +21,7 @@ from rasa.nlu.constants import (
     ENTITY_ATTRIBUTE_TEXT,
     RESPONSE_SELECTOR_DEFAULT_INTENT,
     RESPONSE_SELECTOR_RETRIEVAL_INTENTS,
+    TOKENS_NAMES,
 )
 from rasa.shared.nlu.constants import (
     INTENT,
@@ -32,9 +36,14 @@ from rasa.shared.nlu.constants import (
     RESPONSE,
     RESPONSE_SELECTOR,
     FULL_RETRIEVAL_INTENT_NAME_KEY,
+    TEXT,
 )
 from rasa.constants import RESULTS_FILE, PERCENTAGE_KEY
-from rasa.shared.core.events import ActionExecuted, UserUttered
+from rasa.shared.core.events import (
+    ActionExecuted,
+    EntitiesAdded,
+    UserUttered,
+)
 from rasa.shared.core.trackers import DialogueStateTracker
 from rasa.shared.nlu.training_data.formats.readerwriter import TrainingDataWriter
 from rasa.shared.importers.importer import TrainingDataImporter
@@ -481,13 +490,38 @@ def emulate_loop_rejection(partial_tracker: DialogueStateTracker) -> None:
     partial_tracker.update(ActionExecutionRejected(rejected_action_name))
 
 
+def _get_e2e_entity_evaluation_result(
+    processor: "MessageProcessor",
+    tracker: DialogueStateTracker,
+    prediction: PolicyPrediction,
+) -> Optional[EntityEvaluationResult]:
+    previous_event = tracker.events[-1]
+    if isinstance(previous_event, UserUttered):
+        entities_predicted_by_policies = [
+            entity
+            for prediction_event in prediction.events
+            if isinstance(prediction_event, EntitiesAdded)
+            for entity in prediction_event.entities
+        ]
+        entity_targets = previous_event.entities
+        if entity_targets or entities_predicted_by_policies:
+            text = previous_event.text
+            parsed_message = processor.interpreter.featurize_message(
+                Message(data={TEXT: text})
+            )
+            tokens = parsed_message.get(TOKENS_NAMES[TEXT])
+            return EntityEvaluationResult(
+                entity_targets, entities_predicted_by_policies, tokens, text
+            )
+
+
 def _collect_action_executed_predictions(
     processor: "MessageProcessor",
     partial_tracker: DialogueStateTracker,
     event: ActionExecuted,
     fail_on_prediction_errors: bool,
     circuit_breaker_tripped: bool,
-) -> Tuple[EvaluationStore, PolicyPrediction]:
+) -> Tuple[EvaluationStore, PolicyPrediction, Optional[EntityEvaluationResult]]:
     from rasa.core.policies.form_policy import FormPolicy
 
     action_executed_eval_store = EvaluationStore()
@@ -496,6 +530,8 @@ def _collect_action_executed_predictions(
     gold_action_text = event.action_text
     gold = gold_action_name or gold_action_text
 
+    policy_entity_result = None
+
     if circuit_breaker_tripped:
         prediction = PolicyPrediction([], policy_name=None)
         predicted = "circuit breaker tripped"
@@ -503,6 +539,10 @@ def _collect_action_executed_predictions(
         action, prediction = processor.predict_next_action(partial_tracker)
         predicted = action.name()
 
+        policy_entity_result = _get_e2e_entity_evaluation_result(
+            processor, partial_tracker, prediction
+        )
+
         if (
             prediction.policy_name
             and predicted != gold
@@ -560,7 +600,7 @@ def _collect_action_executed_predictions(
             )
         )
 
-    return action_executed_eval_store, prediction
+    return action_executed_eval_store, prediction, policy_entity_result
 
 
 def _form_might_have_been_rejected(
@@ -577,7 +617,12 @@ async def _predict_tracker_actions(
     agent: "Agent",
     fail_on_prediction_errors: bool = False,
     use_e2e: bool = False,
-) -> Tuple[EvaluationStore, DialogueStateTracker, List[Dict[Text, Any]]]:
+) -> Tuple[
+    EvaluationStore,
+    DialogueStateTracker,
+    List[Dict[Text, Any]],
+    List[EntityEvaluationResult],
+]:
 
     processor = agent.create_processor()
     tracker_eval_store = EvaluationStore()
@@ -594,19 +639,28 @@ async def _predict_tracker_actions(
     tracker_actions = []
     should_predict_another_action = True
     num_predicted_actions = 0
+    policy_entity_results = []
 
     for event in events[1:]:
         if isinstance(event, ActionExecuted):
             circuit_breaker_tripped = processor.is_action_limit_reached(
                 num_predicted_actions, should_predict_another_action
             )
-            (action_executed_result, prediction) = _collect_action_executed_predictions(
+            (
+                action_executed_result,
+                prediction,
+                entity_result,
+            ) = _collect_action_executed_predictions(
                 processor,
                 partial_tracker,
                 event,
                 fail_on_prediction_errors,
                 circuit_breaker_tripped,
             )
+
+            if entity_result:
+                policy_entity_results.append(entity_result)
+
             tracker_eval_store.merge_store(action_executed_result)
             tracker_actions.append(
                 {
@@ -642,7 +696,7 @@ async def _predict_tracker_actions(
         if isinstance(event, UserUttered):
             num_predicted_actions = 0
 
-    return tracker_eval_store, partial_tracker, tracker_actions
+    return tracker_eval_store, partial_tracker, tracker_actions, policy_entity_results
 
 
 def _in_training_data_fraction(action_list: List[Dict[Text, Any]]) -> float:
@@ -665,9 +719,9 @@ async def _collect_story_predictions(
     agent: "Agent",
     fail_on_prediction_errors: bool = False,
     use_e2e: bool = False,
-) -> Tuple[StoryEvaluation, int]:
+) -> Tuple[StoryEvaluation, int, List[EntityEvaluationResult]]:
     """Test the stories from a file, running them through the stored model."""
-    from rasa.test import get_evaluation_metrics
+    from sklearn.metrics import accuracy_score
     from tqdm import tqdm
 
     story_eval_store = EvaluationStore()
@@ -679,16 +733,20 @@ async def _collect_story_predictions(
     logger.info(f"Evaluating {number_of_stories} stories\nProgress:")
 
     action_list = []
+    entity_results = []
 
     for tracker in tqdm(completed_trackers):
         (
             tracker_results,
             predicted_tracker,
             tracker_actions,
+            tracker_entity_results,
         ) = await _predict_tracker_actions(
             tracker, agent, fail_on_prediction_errors, use_e2e
         )
 
+        entity_results.extend(tracker_entity_results)
+
         story_eval_store.merge_store(tracker_results)
 
         action_list.extend(tracker_actions)
@@ -702,25 +760,18 @@ async def _collect_story_predictions(
             success.append(predicted_tracker)
 
     logger.info("Finished collecting predictions.")
-    with warnings.catch_warnings():
-        from sklearn.exceptions import UndefinedMetricWarning
-
-        warnings.simplefilter("ignore", UndefinedMetricWarning)
-        report, precision, f1, accuracy = get_evaluation_metrics(
-            [1] * len(completed_trackers), correct_dialogues
-        )
 
     in_training_data_fraction = _in_training_data_fraction(action_list)
 
+    if len(correct_dialogues):
+        accuracy = accuracy_score([1] * len(correct_dialogues), correct_dialogues)
+    else:
+        accuracy = 0
+
     _log_evaluation_table(
         [1] * len(completed_trackers),
         "END-TO-END" if use_e2e else "CONVERSATION",
-        report,
-        precision,
-        f1,
         accuracy,
-        in_training_data_fraction,
-        include_report=False,
     )
 
     return (
@@ -732,6 +783,7 @@ async def _collect_story_predictions(
             in_training_data_fraction=in_training_data_fraction,
         ),
         number_of_stories,
+        entity_results,
     )
 
 
@@ -781,7 +833,7 @@ async def test(
     generator = await _create_data_generator(stories, agent, max_stories, e2e)
     completed_trackers = generator.generate_story_trackers()
 
-    story_evaluation, _ = await _collect_story_predictions(
+    story_evaluation, _, entity_results = await _collect_story_predictions(
         completed_trackers, agent, fail_on_prediction_errors, e2e
     )
 
@@ -795,29 +847,48 @@ async def test(
         targets, predictions = evaluation_store.serialise()
 
         if out_directory:
-            report, precision, f1, accuracy = get_evaluation_metrics(
+            report, precision, f1, action_accuracy = get_evaluation_metrics(
                 targets, predictions, output_dict=True
             )
 
+            # Add conversation level accuracy to story report.
+            num_failed = len(story_evaluation.failed_stories)
+            num_correct = len(story_evaluation.successful_stories)
+            num_convs = num_failed + num_correct
+            if num_convs:
+                conv_accuracy = num_correct / num_convs
+                report["conversation_accuracy"] = {
+                    "accuracy": conv_accuracy,
+                    "correct": num_correct,
+                    "total": num_convs,
+                }
             report_filename = os.path.join(out_directory, REPORT_STORIES_FILE)
             rasa.shared.utils.io.dump_obj_as_json_to_file(report_filename, report)
             logger.info(f"Stories report saved to {report_filename}.")
+
         else:
-            report, precision, f1, accuracy = get_evaluation_metrics(
+            report, precision, f1, action_accuracy = get_evaluation_metrics(
                 targets, predictions, output_dict=True
             )
 
+        evaluate_entities(
+            entity_results,
+            POLICIES_THAT_EXTRACT_ENTITIES,
+            out_directory,
+            successes,
+            errors,
+            disable_plotting,
+        )
+
     telemetry.track_core_model_test(len(generator.story_graph.story_steps), e2e, agent)
 
     _log_evaluation_table(
         evaluation_store.action_targets,
         "ACTION",
-        report,
-        precision,
-        f1,
-        accuracy,
-        story_evaluation.in_training_data_fraction,
-        include_report=False,
+        action_accuracy,
+        precision=precision,
+        f1=f1,
+        in_training_data_fraction=story_evaluation.in_training_data_fraction,
     )
 
     if not disable_plotting and out_directory:
@@ -842,7 +913,7 @@ async def test(
         "report": report,
         "precision": precision,
         "f1": f1,
-        "accuracy": accuracy,
+        "accuracy": action_accuracy,
         "actions": story_evaluation.action_list,
         "in_training_data_fraction": story_evaluation.in_training_data_fraction,
         "is_end_to_end_evaluation": e2e,
@@ -852,22 +923,25 @@ async def test(
 def _log_evaluation_table(
     golds: List[Any],
     name: Text,
-    report: Dict[Text, Any],
-    precision: float,
-    f1: float,
     accuracy: float,
-    in_training_data_fraction: float,
+    report: Optional[Dict[Text, Any]] = None,
+    precision: Optional[float] = None,
+    f1: Optional[float] = None,
+    in_training_data_fraction: Optional[float] = None,
     include_report: bool = True,
 ) -> None:  # pragma: no cover
     """Log the sklearn evaluation metrics."""
     logger.info(f"Evaluation Results on {name} level:")
     logger.info(f"\tCorrect:          {int(len(golds) * accuracy)} / {len(golds)}")
-    logger.info(f"\tF1-Score:         {f1:.3f}")
-    logger.info(f"\tPrecision:        {precision:.3f}")
+    if f1 is not None:
+        logger.info(f"\tF1-Score:         {f1:.3f}")
+    if precision is not None:
+        logger.info(f"\tPrecision:        {precision:.3f}")
     logger.info(f"\tAccuracy:         {accuracy:.3f}")
-    logger.info(f"\tIn-data fraction: {in_training_data_fraction:.3g}")
+    if in_training_data_fraction is not None:
+        logger.info(f"\tIn-data fraction: {in_training_data_fraction:.3g}")
 
-    if include_report:
+    if include_report and report is not None:
         logger.info(f"\tClassification report: \n{report}")
 
 
@@ -955,7 +1029,9 @@ async def _evaluate_core_model(model: Text, stories_file: Text) -> int:
     agent = Agent.load(model)
     generator = await _create_data_generator(stories_file, agent)
     completed_trackers = generator.generate_story_trackers()
-    story_eval_store, number_of_stories = await _collect_story_predictions(
+
+    # Entities are ignored here as we only compare number of correct stories.
+    story_eval_store, number_of_stories, _ = await _collect_story_predictions(
         completed_trackers, agent
     )
     failed_stories = story_eval_store.failed_stories
