@@ -1,9 +1,11 @@
-import asyncio
 import pprint as pretty_print
 import typing
-from typing import Any, Dict, Text, Optional
-from rasa.cli.utils import print_success, print_error
-from rasa.core.interpreter import NaturalLanguageInterpreter, RasaNLUInterpreter
+from typing import Any, Dict, Optional, Text
+
+from rasa.core.interpreter import RasaNLUInterpreter
+from rasa.shared.nlu.interpreter import NaturalLanguageInterpreter
+from rasa.shared.utils.cli import print_error, print_success
+import rasa.utils.common
 
 if typing.TYPE_CHECKING:
     from rasa.core.agent import Agent
@@ -15,6 +17,7 @@ def pprint(obj: Any):
 
 def chat(
     model_path: Optional[Text] = None,
+    endpoints: Optional[Text] = None,
     agent: Optional["Agent"] = None,
     interpreter: Optional[NaturalLanguageInterpreter] = None,
 ) -> None:
@@ -22,6 +25,7 @@ def chat(
 
     Args:
         model_path: Path to a combined Rasa model.
+        endpoints: Path to a yaml with the action server is custom actions are defined.
         agent: Rasa Core agent (used if no Rasa model given).
         interpreter: Rasa NLU interpreter (used with Rasa Core agent if no
                      Rasa model is given).
@@ -30,7 +34,7 @@ def chat(
     if model_path:
         from rasa.run import create_agent
 
-        agent = create_agent(model_path)
+        agent = create_agent(model_path, endpoints)
 
     elif agent is not None and interpreter is not None:
         # HACK: this skips loading the interpreter and directly
@@ -47,19 +51,18 @@ def chat(
         return
 
     print("Your bot is ready to talk! Type your messages here or send '/stop'.")
-    loop = asyncio.get_event_loop()
     while True:
         message = input()
         if message == "/stop":
             break
 
-        responses = loop.run_until_complete(agent.handle_text(message))
+        responses = rasa.utils.common.run_in_loop(agent.handle_text(message))
         for response in responses:
             _display_bot_response(response)
 
 
 def _display_bot_response(response: Dict):
-    from IPython.display import Image, display  # pytype: disable=import-error
+    from IPython.display import Image, display
 
     for response_type, value in response.items():
         if response_type == "text":
