@@ -370,14 +370,17 @@ class CountVectorsFeaturizer(SparseFeaturizer):
 
         Args:
             attribute: Message attribute for which vocabulary should be updated.
-            new_vocabulary: Set of words to expand the vocabulary with if they are unseen.
+            new_vocabulary: Set of words to expand the vocabulary with if they are
+                unseen.
         """
         existing_vocabulary: Dict[Text, int] = self.vectorizers[attribute].vocabulary
         if len(new_vocabulary) > len(existing_vocabulary):
             rasa.shared.utils.io.raise_warning(
-                f"New data contains vocabulary of size {len(new_vocabulary)} for attribute {attribute} "
-                f"which is larger than the maximum vocabulary size({len(existing_vocabulary)}) "
-                f"of the original model. Some tokens will have to be dropped "
+                f"New data contains vocabulary of size {len(new_vocabulary)} for "
+                f"attribute {attribute} "
+                f"which is larger than the maximum vocabulary size "
+                f"({len(existing_vocabulary)}) of the original model. "
+                f"Some tokens will have to be dropped "
                 f"in order to continue training. It is advised to re-train the "
                 f"model from scratch on the complete data."
             )
@@ -410,11 +413,14 @@ class CountVectorsFeaturizer(SparseFeaturizer):
         current vocabulary size.
 
         Args:
-            attribute: Message attribute for which additional vocabulary size should be computed.
-            existing_vocabulary_size: Current size of vocabulary learnt from the training data.
+            attribute: Message attribute for which additional vocabulary size should
+                be computed.
+            existing_vocabulary_size: Current size of vocabulary learnt from the
+                training data.
 
         Returns:
-            Size of additional vocabulary that should be set aside for incremental training.
+            Size of additional vocabulary that should be set aside for incremental
+            training.
         """
         # Vocabulary expansion for INTENTS, ACTION_NAME
         # and INTENT_RESPONSE_KEY is currently not supported as
@@ -442,7 +448,8 @@ class CountVectorsFeaturizer(SparseFeaturizer):
         So for example - buf_1, buf_2, buf_3... and so on.
 
         Args:
-            attribute: Name of the attribute for which the vocabulary should be expanded.
+            attribute: Name of the attribute for which the vocabulary should be
+            expanded.
         """
         original_vocabulary = self.vectorizers[attribute].vocabulary_
         current_vocabulary_size = len(original_vocabulary)
@@ -552,7 +559,7 @@ class CountVectorsFeaturizer(SparseFeaturizer):
                 )
 
     def _log_vocabulary_stats(self, attribute: Text) -> None:
-        """Logs number of vocabulary slots filled out of the total number of available slots.
+        """Logs number of vocabulary slots filled out of the total available ones.
 
         Args:
             attribute: Message attribute for which vocabulary stats are logged.
