@@ -31,19 +31,20 @@ INTENT_MESSAGE_PREFIX = "/"
 PACKAGE_NAME = "rasa"
 NEXT_MAJOR_VERSION_FOR_DEPRECATIONS = "3.0.0"
 
-CONFIG_SCHEMA_FILE = "shared/nlu/training_data/schemas/config.yml"
+MODEL_CONFIG_SCHEMA_FILE = "shared/utils/schemas/model_config.yml"
+CONFIG_SCHEMA_FILE = "shared/utils/schemas/config.yml"
 RESPONSES_SCHEMA_FILE = "shared/nlu/training_data/schemas/responses.yml"
 SCHEMA_EXTENSIONS_FILE = "shared/utils/pykwalify_extensions.py"
 LATEST_TRAINING_DATA_FORMAT_VERSION = "2.0"
 
-DOMAIN_SCHEMA_FILE = "utils/schemas/domain.yml"
+DOMAIN_SCHEMA_FILE = "shared/utils/schemas/domain.yml"
 
 DEFAULT_SESSION_EXPIRATION_TIME_IN_MINUTES = 60
 DEFAULT_CARRY_OVER_SLOTS_TO_NEW_SESSION = True
 
 DEFAULT_NLU_FALLBACK_INTENT_NAME = "nlu_fallback"
 
-DEFAULT_E2E_TESTS_PATH = "tests"
+DEFAULT_E2E_TESTS_PATH = "."
 TEST_STORIES_FILE_PREFIX = "test_"
 
 DEFAULT_LOG_LEVEL = "INFO"
